@@ -1,5 +1,5 @@
-package Devel::Trace::Subs 0.17;
-use 5.012;
+package Devel::Trace::Subs;
+use 5.008;
 use strict;
 use warnings;
 
@@ -10,6 +10,8 @@ use Devel::Trace::Subs::Text qw(text);
 use Exporter;
 use Storable;
 
+our $VERSION = '0.18';
+
 our @ISA = qw(Exporter);
 our @EXPORT_OK = qw(
                     trace
