@@ -1,5 +1,5 @@
-package Devel::Trace::Subs::HTML 0.17;
-use 5.012;
+package Devel::Trace::Subs::HTML;
+use 5.008;
 use strict;
 use warnings;
 
@@ -7,6 +7,8 @@ use Data::Dumper;
 use Exporter;
 use HTML::Template;
 
+our $VERSION = '0.18';
+
 our @ISA = qw(Exporter);
 our @EXPORT_OK = qw(html);
 
